# Getting Started

## Requirements

* Python 3.8+


## Installation

The `armasec` package can be installed like any other python package. It is available on
[PyPI](https://pypi.org/project/armasec/)


### uv

To install via `uv`, simply run:

```bash
uv add armasec
```


### Poetry

To install via `poetry`, simply run:

```bash
poetry add armasec
```


### Pip

To install directly with `pip`, simply run:

```bash
pip install armasec
```
